package de.thdeg.greiner.superpangworld.game;

import de.thdeg.greiner.superpangworld.gameview.GameView;
import de.thdeg.greiner.superpangworld.graphics.*;

import java.awt.*;
import java.awt.event.KeyEvent;
import java.util.Arrays;

/** Der Manager zur Verwaltung der Spielschleife. */
public class GameLoopManager {

    private static final boolean DIAGONAL_MOVEMENT_ALLOWED = false;

    private GameView gameView;
    private Bubble bubble;
    private Harpoon harpoon;

    private LevelProgressBar levelProgressBar;
    private LevelLabel levelLabel;
    private ScoreLabel scoreLabel;

    private Player player;

    /** Erzeugt den GameLoopManager mit Standardwerten. */
    public GameLoopManager() {
        this.gameView = new GameView();
        this.gameView.setWindowTitle("Super Pang World");
        this.gameView.setStatusText("Andreas Greiner - Java Programmierung SS 2021");
        this.gameView.setWindowIcon("Target.png");

        this.bubble = new Bubble(gameView);
        this.harpoon = new Harpoon(gameView);

        this.levelProgressBar = new LevelProgressBar(gameView);
        this.levelLabel = new LevelLabel(gameView);
        this.scoreLabel = new ScoreLabel(gameView);

        this.player = new Player(gameView);

        gameView.setColorForBlockImage('k',Color.LIGHT_GRAY);
    }

    /** Startet das Spiel. */
    public void startGame() {
        while(true){
            updateUserInputs();


            bubble.updatePosition();
            bubble.addToCanvas();
            harpoon.addToCanvas();

            levelProgressBar.addToCanvas();
            levelLabel.addToCanvas();
            scoreLabel.addToCanvas();

            player.addToCanvas();

            gameView.printCanvas();
        }
    }

    void updateUserInputs() {
        Integer[] gedruekteTasten = gameView.getKeyCodesOfCurrentlyPressedKeys();
        if(Arrays.stream(gedruekteTasten).anyMatch(k -> k == KeyEvent.VK_SPACE)){
            player.shoot();
        }
        for (int keyCode : gedruekteTasten) {
            switch(keyCode) {
                case KeyEvent.VK_LEFT:
                    player.left();
                    break;
                case KeyEvent.VK_RIGHT:
                    player.right();
                    break;
                default:
                    continue;
            }
            if(!DIAGONAL_MOVEMENT_ALLOWED){
                return;
            }
        }
    }


}
